Jido.Signal.Bus.Snapshot.SnapshotRef (Jido Signal v2.1.1)

A lightweight reference to a snapshot stored in :persistent_term. Contains only the metadata needed for listing and lookup.

Fields

  • id - Unique identifier for the snapshot
  • path - The path pattern used to filter signals
  • created_at - When the snapshot was created

Summary

Functions

Returns the Zoi schema for SnapshotRef

Types

t()

@type t() :: %Jido.Signal.Bus.Snapshot.SnapshotRef{
  created_at: any(),
  id: binary(),
  path: binary()
}

Functions

schema()

Returns the Zoi schema for SnapshotRef